%--------------------------------------------------------------------------
% ReadCir function reads in a Spice-like network list stored in a
% text file. The input is just the name of the netlist file
%       file_name: name of text file containing the netlist
% The output is the datastructure NetListData:
%       NetListData.types : cell array of types 
%       NetListData.names : cell array of names
%       NetListData.nodes : matrix of node numbers
%       NetListData.parameters : array of element values
%--------------------------------------------------------------------------

function [NetListData] = ReadCirc(file_name)

fid = fopen(file_name);

tline = fgetl(fid);
index = 1;
types{1} = 0;       %cell array of types
names{1} = 0;       %cell array of names
nodes = [0 0 0 0];  %matrix of node numbers
parameters = 0;     %array of branch parameters

while ischar(tline)
    if(~strcmp(tline,'') && ~strcmp(tline(1),'%'))
        types{index} = char(sscanf(tline,'%3s %*20s %*d %*d %*d %*d %*f'))';
        names{index} = char(sscanf(tline,'%*3s %20s %*d %*d %*d %*d %*f'))';
        nodes(index, :) = sscanf(tline,'%*3s %*20s %d %d %d %d %*f');
        parameters(index) = sscanf(tline,'%*3s %*20s %*d %*d %*d %*d %f');
        index = index + 1;    
    end %if
    tline = fgetl(fid);
end

fclose(fid);

%return data
NetListData.types = types;
NetListData.names = names;
NetListData.nodes = nodes;
NetListData.parameters = parameters;

